# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""Constants and helpers for this testing suite"""


import pathlib
from typing import Counter

from delivery.products import ProductMetadata

TEST_RESTORE_METADATA = ProductMetadata("EVLA", "17B-403", "restored_cms", None, None, "60468.6349189817")
RESTORE_AUXPRODUCTS_NAME = "unknown.auxproducts.tgz"


def get_expected_files_and_dirs_for_restore(
    containing_dir: str, do_include_flagtemplate: bool = False
) -> tuple[set[pathlib.Path], Counter[str]]:
    expected_dirs_to_file_counts = Counter(
        {
            f"{containing_dir}/17B-403.sb34574962.eb34577590_000.58035.544146898144.ms": 119,
            f"{containing_dir}/weblog_calibration": 1495,
            f"{containing_dir}/weblog_restore": 90,
        }
    )
    expected_files = {
        f"{containing_dir}/PPR_restore.xml",
        f"{containing_dir}/PPR_restore.xml",
        f"{containing_dir}/17B-403.sb34574962.eb34577590_000.58035.544146898144.ms.calapply.txt",
        f"{containing_dir}/casa_piperestorescript.py",
        f"{containing_dir}/casa_pipescript.py",
        f"{containing_dir}/casa_commands.log",
        f"{containing_dir}/PPR_calibration.xml",
        f"{containing_dir}/flux.csv",
        f"{containing_dir}/unknown.session_1.caltables.tgz",
    }
    if do_include_flagtemplate:
        expected_files.add(f"{containing_dir}/17B-403.sb34574962.eb34577590_000.58035.544146898144.flagtemplate.txt")
    expected_files = {pathlib.Path(f) for f in expected_files}
    return expected_files, expected_dirs_to_file_counts
