#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
from __future__ import annotations

import json
import logging

import requests
from pycapo import CapoConfig

from workspaces.capability.helpers_interfaces import ParameterIF

logger = logging.getLogger(__name__)


class Parameter(ParameterIF):
    def json(self) -> str:
        pass


class CasaMatrixClient:
    """
    Methods for interacting with the CASA version matrix.
    """

    @staticmethod
    def casa_recipe(
        capability: str, version: str | None = None, telescope: str | None = None, version_path: str | None = None
    ) -> str:
        recipe = ""
        matrix_url = (
            CapoConfig().get("edu.nrao.workspaces.CapabilitySettings.externalServiceUrl") + "/casa_matrix/recipe"
        )

        params = {"capability": capability, "version": version, "telescope": telescope, "version_path": version_path}

        response = requests.get(matrix_url, json=params)

        if response.ok:
            recipe = json.loads(response.text)
        else:
            logger.critical(f"Unable to fetch a CASA recipe from the metrix service with params: {params}")

        return recipe
